@@ -27,12 +27,15 @@ __all__ = [
     'image_from_mpl',
     'image_from_file',
     'image_from_url',
+    'button',
 ]
 
 image_from_mpl= app.image_from_mpl
 image_from_file = app.image_from_file
 image_from_url = app.image_from_url
 
+button = app.button
+
 box = app.box
 add_srcipt = app.add_srcipt
 dataTable = app.dataTable
