@@ -90,6 +90,11 @@ class StyleProp():
         p = self.__cp.get_prop('styles.width')
         return StrTypePropInfo(p)
 
+    def make_center(self):
+        self.set('display', 'flex').set('justify-content',
+                                        'center').set('align-items', 'center')
+        return self
+
     def set_width(self, value: Union[StrTypePropInfo, str]):
         self.__cp.set_prop('styles.width', value)
         return self
