@@ -14,6 +14,7 @@ from pyvisflow.core.components.select import Select
 from pyvisflow.core.components.text import Text
 from pyvisflow.core.components.file import File
 from pyvisflow.core.components.image import Image
+from pyvisflow.core.components.button import Button
 
 from pyvisflow.core.layout import MarkdownLayout
 from pyvisflow.core.props import BoolTypePropInfo
@@ -65,7 +66,12 @@ class BoxContainer(Container):
 
     def image_from_url(self,url:str):
         return self.__image(url)
-            
+    
+    def button(self,text:str):
+        cp = Button(text)
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
 
     def image_from_file(self,path:str):
         with open(path,'rb') as f:
